import React, { useEffect, useState } from "react";
import { useNavigate } from "react-router-dom";
import api from "../api";

const CoursesList = ({ courses }) => {
  const [detailedCourses, setDetailedCourses] = useState([]);
  const [loading, setLoading] = useState(true);
  const navigate = useNavigate();

  const handleCourseClick = (courseId) => {
    if (!isNaN(courseId)) {
      navigate(`/courses/${courseId}`);
    } else {
      console.error("Invalid course ID:", courseId);
    }
  };
  
  useEffect(() => {
    const fetchCourseDetails = async () => {
      const auth_token = localStorage.getItem("auth_token");
      const auth_token_type = localStorage.getItem("auth_token_type");
      const token = `${auth_token_type} ${auth_token}`;

      try {
        const detailedCoursesPromises = courses.map((course) =>
          api.get(`/courses/edit/${course.id}`, {
            headers: { Authorization: token },
          })
        );

        const detailedCoursesResponses = await Promise.all(detailedCoursesPromises);
        const detailedCoursesData = detailedCoursesResponses.map(
          (response) => response.data.result
        );

        setDetailedCourses(detailedCoursesData);
      } catch (error) {
        console.log("Error fetching course details:", error);
      } finally {
        setLoading(false);
      }
    };

    fetchCourseDetails();
  }, [courses]);

  if (loading) {
    return <div>Loading...</div>;
  }

  return (
    <div className="bg-white shadow-md p-6 rounded-lg" style={{ fontFamily: 'Trebuchet' }}>
      <h2 className="text-2xl font-bold mb-4 text-black">Seus Cursos</h2>
      {detailedCourses.length > 0 ? (
        <ul className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-4">
          {detailedCourses.map((course) => (
            <li
              key={course.id}
              className="flex flex-col items-center bg-gray-100 p-4 rounded-lg cursor-pointer hover:bg-gray-200 transition"
              onClick={() => handleCourseClick(course.id)}
            >
              {course.image_url ? (
                <img
                  src={course.image_url}
                  alt={course.course_name}
                  className="w-full h-32 object-cover rounded-md mb-2"
                />
              ) : (
                <div className="w-full h-32 bg-gray-300 rounded-md mb-2 flex items-center justify-center">
                  <span className="text-gray-600">Sem Imagem</span>
                </div>
              )}
              <div className="text-xl font-semibold text-center line-clamp-1 text-black">
                {course.course_name}
              </div>
              <p className="text-black text-center line-clamp-2">
                {course.description}
              </p>
            </li>
          ))}
        </ul>
      ) : (
        <div>Nenhum curso encontrado.</div>
      )}
    </div>
  );
};

export default CoursesList;
