import React, { useEffect, useState } from "react";
import { useNavigate } from "react-router-dom";
import api from "../api";

const CoursesListOp2 = ({ courses }) => {
  const [detailedCourses, setDetailedCourses] = useState([]);
  const [loading, setLoading] = useState(true);
  const navigate = useNavigate();

  const handleCourseClick = (courseId) => {
    if (!isNaN(courseId)) {
      navigate(`/courses/${courseId}`);
    } else {
      console.error("Invalid course ID:", courseId);
    }
  };

  useEffect(() => {
    const fetchCourseDetails = async () => {
      const auth_token = localStorage.getItem("auth_token");
      const auth_token_type = localStorage.getItem("auth_token_type");
      const token = `${auth_token_type} ${auth_token}`;

      try {
        const detailedCoursesPromises = courses.map((course) =>
          api.get(`/courses/edit/${course.id}`, {
            headers: { Authorization: token },
          })
        );

        const detailedCoursesResponses = await Promise.all(detailedCoursesPromises);
        const detailedCoursesData = detailedCoursesResponses.map(
          (response) => response.data.result
        );

        setDetailedCourses(detailedCoursesData);
      } catch (error) {
        console.log("Error fetching course details:", error);
      } finally {
        setLoading(false);
      }
    };

    fetchCourseDetails();
  }, [courses]);

  if (loading) {
    return <div>Loading...</div>;
  }

  return (
    <div className="bg-white shadow-md p-4 rounded-lg h-full" style={{ fontFamily: 'Euphemia UCAS' }}>
      <h2 className="text-2xl font-bold mb-4 text-black">Seus Cursos</h2>
      {detailedCourses.length > 0 ? (
        <ul className="space-y-4 overflow-y-auto max-h-[32rem]">
          {detailedCourses.map((course) => (
            <li
              key={course.id}
              className="flex bg-gray-100 p-4 rounded-lg cursor-pointer hover:bg-gray-200 transition"
              onClick={() => handleCourseClick(course.id)}
            >
              <div className="w-1/4 flex-shrink-0">
                {course.image_url ? (
                  <img
                    src={course.image_url}
                    alt={course.course_name}
                    className="w-full h-32 object-cover rounded-md"
                  />
                ) : (
                  <div className="w-full h-32 bg-gray-300 rounded-md flex items-center justify-center">
                    <span className="text-gray-600">Sem Imagem</span>
                  </div>
                )}
                <div className="text-center text-xl font-semibold mt-2 line-clamp-1 text-black">
                  {course.course_name}
                </div>
              </div>
              <div className="ml-4 w-3/4">
                <p className="text-black line-clamp-3">{course.description}</p>
              </div>
            </li>
          ))}
        </ul>
      ) : (
        <div>Nenhum curso encontrado.</div>
      )}
    </div>
  );
};

export default CoursesListOp2;
