import React, { useState } from "react";
import { useNavigate } from "react-router-dom";
import { toast } from "react-toastify";

const Sidebar = ({ user }) => {
  const [menuOpen, setMenuOpen] = useState(false);
  const navigate = useNavigate();

  const handleMouseEnter = () => {
    setMenuOpen(true);
  };

  const handleMouseLeave = () => {
    setMenuOpen(false);
  };

  const onClickHandler = (event) => {
    event.preventDefault();
    localStorage.removeItem("auth_token");
    localStorage.removeItem("auth_token_type");

    toast("Até logo!", {
      position: "top-right",
      autoClose: 5000,
      hideProgressBar: false,
      closeOnClick: true,
      pauseOnHover: true,
      draggable: true,
      progress: undefined,
    });

    setTimeout(() => {
      window.location.reload();
    }, 1000);
  };

  const handleCreateCourse = () => {
    navigate("/createCourses");
    setMenuOpen(false);
  };

  return (
    <div className="w-1/8 bg-[#F4A163] h-full flex flex-col justify-between items-center p-4 relative" style={{ minHeight: "200px", fontFamily: 'Euphemia UCAS' }}>
      <div className="flex-grow">
        <img
          className="w-16 h-16 mx-auto rounded-full border-4 border-white"
          alt="profile"
          src={user.profile || "https://via.placeholder.com/150"}
        />
        <div className="text-center mt-2 text-white font-medium">
          {user.name.split(" ")[0].length > 11
            ? `${user.name.split(" ")[0].substring(0, 11)}...`
            : user.name.split(" ")[0]}
        </div>
      </div>

      <div
        onMouseEnter={handleMouseEnter}
        onMouseLeave={handleMouseLeave}
        className="relative"
      >
        <button
          id="dropdownHoverButton"
          className="text-white bg-[#E8C36A] hover:bg-[#F4A163] focus:ring-4 focus:outline-none focus:ring-blue-300 font-medium rounded-lg text-sm px-5 py-2.5 text-center inline-flex items-center"
          type="button"
        >
          Menu
          <svg
            className={`w-2.5 h-2.5 ms-3 transform transition-transform duration-200 ${
              menuOpen ? "rotate-180" : ""
            }`}
            aria-hidden="true"
            xmlns="http://www.w3.org/2000/svg"
            fill="none"
            viewBox="0 0 10 6"
          >
            <path
              stroke="currentColor"
              strokeLinecap="round"
              strokeLinejoin="round"
              strokeWidth="2"
              d="m1 1 4 4 4-4"
            />
          </svg>
        </button>

        {menuOpen && (
          <div
            id="dropdownHover"
            className="absolute left-0 bottom-10 z-10 bg-white divide-y divide-gray-100 rounded-lg shadow w-44"
          >
            <ul className="py-2 text-sm text-gray-700" aria-labelledby="dropdownHoverButton">
              <li>
                <a
                  onClick={() => {
                    navigate("/");
                    setMenuOpen(false);
                  }}
                  className="block px-4 py-2 hover:bg-gray-100"
                >
                  Início
                </a>
              </li>
              <li>
                <a
                  onClick={() => {
                    navigate("/profile");
                    setMenuOpen(false);
                  }}
                  className="block px-4 py-2 hover:bg-gray-100"
                >
                  Perfil
                </a>
              </li>
              {user.role === "admin" && (
                <li>
                  <a
                    onClick={handleCreateCourse}
                    className="block px-4 py-2 hover:bg-gray-100 text-blue-600"
                  >
                    Criar Curso
                  </a>
                </li>
              )}
            </ul>
            <div className="py-2">
              <a
                onClick={onClickHandler}
                href="#"
                className="block px-4 py-2 text-sm text-red-700 hover:bg-red-100"
              >
                Sair
              </a>
            </div>
          </div>
        )}
      </div>
    </div>
  );
};

export default Sidebar;
