import React, { useState } from "react";
import { useNavigate } from "react-router-dom";
import api from './../api';
import { toast } from "react-toastify";

export default function Forgot() {
  const [forgotForm, setForgotForm] = useState({
    email: "",
    new_password: "",
  });

  const navigate = useNavigate();

  const onChangeForm = (label, event) => {
    switch (label) {
      case "email":
        setForgotForm({ ...forgotForm, email: event.target.value });
        break;
      case "new_password":
        setForgotForm({ ...forgotForm, new_password: event.target.value });
        break;
    }
  };

  const onSubmitHandler = async (event) => {
    event.preventDefault();
    console.log(forgotForm);
    await api.post("/auth/forgot-password", forgotForm)
      .then((response) => {
        toast.success(response.data.detail);
        setTimeout(() => {
          window.location.reload();
        }, 1000);
      })
      .catch((error) => {
        toast.error(error.response.data.detail);
      });
  };

  return (
    <React.Fragment>
      <div>
        <h1 className="text-3xl font-bold text-center mb-4 cursor-pointer">
          Esqueceu sua senha?
        </h1>
        <p className="w-80 text-center text-sm mb-8 font-semibold text-gray-700 tracking-wide cursor-pointer mx-auto">
          Agora atualize a senha da sua conta!
        </p>
      </div>
      <form onSubmit={onSubmitHandler}>
        <div className="space-y-4">
          <input
            type="email"
            placeholder="Email"
            className="block text-sm py-3 px-4 rounded-lg w-full border outline-none focus:ring focus:outline-none focus:bg-[#E8C36A]"
            onChange={(event) => onChangeForm("email", event)}
          />
          <input
            type="password"
            placeholder="Nova Senha"
            className="block text-sm py-3 px-4 rounded-lg w-full border outline-none focus:ring focus:outline-none focus:bg-[#E8C36A]"
            onChange={(event) => onChangeForm("new_password", event)}
          />
        </div>
        <div className="text-center mt-6">
          <button
            type="submit"
            className="py-3 w-64 text-xl text-white bg-[#E8C36A] rounded-2xl hover:bg-[#F4A163] active:bg-[#F4A163] outline-none"
          >
            Atualizar Senha
          </button>
          <p className="mt-4 text-sm">
            Já tem uma conta?{" "}
            <span
              className="underline cursor-pointer"
              onClick={() => navigate("/login")}
            >
              Fazer Login
            </span>
          </p>
        </div>
      </form>
    </React.Fragment>
  );
}
