import React, { useState } from "react";
import { useNavigate } from "react-router-dom";
import api from './../api';
import { toast } from "react-toastify";

export default function Login() {
  const [loginForm, setLoginform] = useState({
    username: "",
    password: "",
  });
  const navigate = useNavigate(); 

  const onChangeForm = (label, event) => {
    switch (label) {
      case "username":
        setLoginform({ ...loginForm, username: event.target.value });
        break;
      case "password":
        setLoginform({ ...loginForm, password: event.target.value });
        break;
    }
  };

  const onSubmitHandler = async (event) => {
    event.preventDefault();
    
    try {
      const response = await api.post("/auth/login", loginForm);
      
      localStorage.setItem("auth_token", response.data.result.access_token.access_token);
      localStorage.setItem("auth_token_type", response.data.result.access_token.token_type);
      localStorage.setItem("token_expiration", response.data.result.access_token.expiration_time);

      toast.success(response.data.detail);
      setTimeout(() => {
        window.location.reload();
      }, 1000);
    } catch (error) {
      console.log(error);
      toast.error(error.response.data.detail);
    }
  };  

  return (
    <React.Fragment>
      <div>
        <h1 className="text-3xl font-bold text-center mb-4 cursor-pointer" style={{ fontFamily: 'Euphemia UCAS Bold' }}>
         Por favor, faça login na sua conta!
        </h1>
      </div>
      <form onSubmit={onSubmitHandler}>
        <div className="space-y-4">
          <input
            type="text"
            placeholder="Usuário"
            className="block text-sm py-3 px-4 rounded-lg w-full border outline-none focus:ring focus:outline-none focus:bg-[#E8C36A]"
            onChange={(event) => onChangeForm("username", event)}
            style={{ fontFamily: 'Euphemia UCAS' }}
          />
          <input
            type="password"
            placeholder="Senha"
            className="block text-sm py-3 px-4 rounded-lg w-full border outline-none focus:ring focus:outline-none focus:bg-[#E8C36A]"
            onChange={(event) => onChangeForm("password", event)}
            style={{ fontFamily: 'Euphemia UCAS' }}
          />
        </div>
        <div className="text-center mt-6">
          <button
            type="submit"
            className="py-3 w-64 text-xl text-white bg-[#E8C36A] rounded-2xl hover:bg-[#F4A163] active:bg-[#F4A163] outline-none"
            style={{ fontFamily: 'Euphemia UCAS' }}
          >
            Fazer Login
          </button>
          <p className="mt-4 text-sm" style={{ fontFamily: 'Euphemia UCAS' }}>
            Você não tem uma conta?{" "}
            <span
              className="underline cursor-pointer"
              onClick={() => navigate("/register")}
            >
              Registre-se
            </span>{" "}
            ou{" "}
            <span
              className="underline cursor-pointer"
              onClick={() => navigate("/forgot")}
            >
              Esqueceu a Senha?
            </span>
          </p>
        </div>
      </form>
    </React.Fragment>
  );
}
