/* eslint-disable default-case */
import React, { useState } from "react";
import DatePicker from "react-datepicker";
import "react-datepicker/dist/react-datepicker.css";
import { useNavigate } from "react-router-dom";
import api from './../api';
import { toast } from "react-toastify";

export default function Register() {
  const navigate = useNavigate();

  const [formRegister, setFormRegister] = useState({
    name: "",
    username: "",
    email: "",
    password: "",
    phone_number: "",
    cpf: "",
    birth: "",
    institution: "",
    profile: "",
  });

  const [birthDate, setBirthDate] = useState(null);

  const formatDate = (date) => {
    let d = new Date(date),
      month = "" + (d.getMonth() + 1),
      day = "" + d.getDate(),
      year = d.getFullYear();

    if (month.length < 2) month = "0" + month;
    if (day.length < 2) day = "0" + day;
    return [day, month, year].join("-");
  };

  const onChangeForm = (label, event) => {
    switch (label) {
      case "name":
        setFormRegister({ ...formRegister, name: event.target.value });
        break;
      case "username":
        setFormRegister({ ...formRegister, username: event.target.value });
        break;
      case "email":
        const email_validation = /\S+@\S+\.\S+/;
        if (email_validation.test(event.target.value)) {
          setFormRegister({ ...formRegister, email: event.target.value });
        }
        break;
      case "phone_number":
        setFormRegister({ ...formRegister, phone_number: event.target.value });
        break;
      case "password":
        setFormRegister({ ...formRegister, password: event.target.value });
        break;
      case "institution":
        setFormRegister({ ...formRegister, institution: event.target.value });
        break;
      case "birth":
        setBirthDate(event);
        setFormRegister({ ...formRegister, birth: formatDate(event) });
        break;
      case "cpf":
        setFormRegister({ ...formRegister, cpf: event.target.value });
        break;
    }
  };

  const onSubmitHandler = async (event) => {
    event.preventDefault();
    console.log(formRegister);
    await api.post("/auth/register", formRegister)
      .then((response) => {
        toast.success(response.data.detail);
        setTimeout(() => {
          navigate("/login");
        }, 1000);
      })
      .catch((error) => {
        console.log(error);
        toast.error(error.response.data.detail);
      });
  };

  return (
    <React.Fragment>
      <div>
        <h1 className="text-3xl font-bold text-center mb-4 cursor-pointer" style={{ fontFamily: 'Euphemia UCAS Bold' }}>
          Criar Uma Conta
        </h1>
      </div>
      <form onSubmit={onSubmitHandler}>
        <div className="space-y-4">
          <input
            type="text"
            placeholder="Nome Completo"
            className="block text-sm py-3 px-4 rounded-lg w-full border outline-none focus:ring focus:outline-none focus:bg-[#E8C36A]"
            onChange={(event) => {
              onChangeForm("name", event);
            }}
          />
          <DatePicker
            className="block text-sm py-3 px-4 rounded-lg w-full border outline-none focus:ring focus:outline-none focus:bg-[#E8C36A]"
            dateFormat="dd-MM-yyyy"
            placeholderText="Data de Nascimento"
            selected={birthDate}
            onChange={(event) => {
              onChangeForm("birth", event);
            }}
          />
          <input
            type="text"
            placeholder="Universidade ou Instituição"
            className="block text-sm py-3 px-4 rounded-lg w-full border outline-none focus:ring focus:outline-none focus:bg-[#E8C36A]"
            onChange={(event) => {
              onChangeForm("institution", event);
            }}
          />
          <input
            type="text"
            placeholder="Usuário"
            className="block text-sm py-3 px-4 rounded-lg w-full border outline-none focus:ring focus:outline-none focus:bg-[#E8C36A]"
            onChange={(event) => {
              onChangeForm("username", event);
            }}
          />
          <input
            type="number"
            placeholder="Número de Telefone"
            className="block text-sm py-3 px-4 rounded-lg w-full border outline-none focus:ring focus:outline-none focus:bg-[#E8C36A]"
            onChange={(event) => {
              onChangeForm("phone_number", event);
            }}
          />
          <input
            type="text"
            placeholder="CPF"
            className="block text-sm py-3 px-4 rounded-lg w-full border outline-none focus:ring focus:outline-none focus:bg-[#E8C36A]"
            onChange={(event) => {
              onChangeForm("cpf", event);
            }}
          />
          <input
            type="email"
            placeholder="Email"
            className="block text-sm py-3 px-4 rounded-lg w-full border outline-none focus:ring focus:outline-none focus:bg-[#E8C36A]"
            onChange={(event) => {
              onChangeForm("email", event);
            }}
          />
          <input
            type="password"
            placeholder="Senha"
            className="block text-sm py-3 px-4 rounded-lg w-full border outline-none focus:ring focus:outline-none focus:bg-[#E8C36A]"
            onChange={(event) => {
              onChangeForm("password", event);
            }}
          />
        </div>
        <div className="text-center mt-6">
          <button
            type="submit"
            className="py-3 w-64 text-xl text-white bg-[#E8C36A] rounded-2xl hover:bg-[#F4A163] active:bg-[#F4A163] outline-none"
          >
            Criar Conta
          </button>
          <p className="mt-4 text-sm">
            Já tem uma conta?{" "}
            <span
              className="underline cursor-pointer"
              onClick={() => navigate("/login")}
            >
              Faça o Login
            </span>
          </p>
        </div>
      </form>
    </React.Fragment>
  );
}
