import React, { useEffect, useState } from "react";
import { useNavigate } from "react-router-dom";
import api from "../api";
import { toast } from "react-toastify";
import Sidebar from "../components/Sidebar";

export default function Profile() {
  const [user, setUser] = useState(null);
  const [loading, setLoading] = useState(true);
  const navigate = useNavigate();

  useEffect(() => {
    const auth_token = localStorage.getItem("auth_token");
    const auth_token_type = localStorage.getItem("auth_token_type");
    const token = `${auth_token_type} ${auth_token}`;

    api
      .get("/users/", {
        headers: { Authorization: token },
      })
      .then((response) => {
        console.log(response.data); 
        setUser(response.data.result);
      })
      .catch((error) => {
        console.log(error);
      })
      .finally(() => {
        setLoading(false);
      });

  }, []);
  
  const onClickHandler = (event) => {
    event.preventDefault();
    localStorage.removeItem("auth_token");
    localStorage.removeItem("auth_token_type");

    toast("See You!", {
      position: "top-right",
      autoClose: 5000,
      hideProgressBar: false,
      closeOnClick: true,
      pauseOnHover: true,
      draggable: true,
      progress: undefined,
    });

    setTimeout(() => {
      window.location.reload();
    }, 1000)
  };

  if (loading) {
    return <div className="text-center mt-20">Loading...</div>;
  }

  return (
    <div className="bg-white font-sans h-screen w-full flex" style={{ fontFamily: 'Euphemia UCAS' }}> {/* Fundo branco e fonte configurada */}
      <Sidebar user={user} />

      <div className="flex-1 h-full p-4">
        <div className="bg-white shadow-md p-6 rounded-lg mb-4">
          <div className="text-center text-2xl font-bold mb-4 text-black">Perfil</div>
          <div className="text-left font-light text-lg text-black">
            <div>Nome: {user.name}</div>
            <div>Email: {user.email}</div>
            <div>Instituição: {user.institution}</div>
            <div>Telefone: {user.phone_number}</div>
            <button
              onClick={onClickHandler}
              className="mt-4 py-2 px-6 bg-red-600 text-white rounded-md"
            >
              Sair
            </button>
          </div>
        </div>
      </div>
    </div>
  );
}
